@@ -23,8 +23,9 @@ from ..dashboard_methods import *
 class PredictionSummaryComponent(ExplainerComponent):
     def __init__(self, explainer, title="Prediction Summary", name=None,
                     hide_index=False, hide_percentile=False, 
-                    hide_title=False, hide_selector=False,
-                    pos_label=None, index=None, percentile=True, **kwargs):
+                    hide_title=False,  hide_subtitle=False, hide_selector=False,
+                    pos_label=None, index=None, percentile=True,
+                    description=None, **kwargs):
         """Shows a summary for a particular prediction
 
         Args:
@@ -38,11 +39,13 @@ class PredictionSummaryComponent(ExplainerComponent):
             hide_index (bool, optional): hide index selector. Defaults to False.
             hide_percentile (bool, optional): hide percentile toggle. Defaults to False.
             hide_title (bool, optional): hide title. Defaults to False.
+            hide_subtitle (bool, optional): Hide subtitle. Defaults to False.
             hide_selector (bool, optional): hide pos label selectors. Defaults to False.
             pos_label ({int, str}, optional): initial pos label. 
                         Defaults to explainer.pos_label
             index ({int, str}, optional): Index to display prediction summary for. Defaults to None.
             percentile (bool, optional): Whether to add the prediction percentile. Defaults to True.
+
         """
         super().__init__(explainer, title, name)
 
@@ -51,10 +54,10 @@ class PredictionSummaryComponent(ExplainerComponent):
 
     def layout(self):
         return dbc.Card([
-            dbc.CardHeader([
-                make_hideable(
-                html.H3("Predictions summary:"), hide=self.hide_title), 
-            ]),
+            make_hideable(
+                dbc.CardHeader([
+                    html.H3(self.title), 
+                ]), hide=self.hide_title), 
             dbc.CardBody([
                 dbc.Row([
                     make_hideable(
@@ -108,9 +111,10 @@ class ImportancesComponent(ExplainerComponent):
     def __init__(self, explainer, title="Feature Importances", name=None,
                         subtitle="Which features had the biggest impact?",
                         hide_type=False, hide_depth=False, hide_cats=False,
-                        hide_title=False, hide_selector=False,
+                        hide_title=False,  hide_subtitle=False, hide_selector=False,
                         pos_label=None, importance_type="shap", depth=None, 
-                        cats=True, no_permutations=False, **kwargs):
+                        cats=True, no_permutations=False,
+                        description=None, **kwargs):
         """Display features importances component
 
         Args:
@@ -129,6 +133,7 @@ class ImportancesComponent(ExplainerComponent):
             hide_cats (bool, optional): Hide group cats toggle. 
                         Defaults to False.
             hide_title (bool, optional): hide title. Defaults to False.
+            hide_subtitle (bool, optional): Hide subtitle. Defaults to False.
             hide_selector (bool, optional): hide pos label selectors. 
                         Defaults to False.
             pos_label ({int, str}, optional): initial pos label. 
@@ -140,6 +145,8 @@ class ImportancesComponent(ExplainerComponent):
             cats (bool, optional): Group categoricals. Defaults to True.
             no_permutations (bool, optional): Do not use the permutation
                 importances for this component. Defaults to False. 
+            description (str, optional): Tooltip to display when hover over
+                component title. When None default text is shown. 
         """
         super().__init__(explainer, title, name)
 
@@ -157,19 +164,27 @@ class ImportancesComponent(ExplainerComponent):
         if self.explainer.y_missing or self.no_permutations:
             self.hide_type = True
             self.importance_type = 'shap'
+        if self.description is None: self.description = f"""
+        Shows the features sorted from most important to least important. Can 
+        be either sorted by absolute SHAP value (average absolute impact of 
+        the feature on final prediction) or by permutation importance (how much
+        does the model get worse when you shuffle this feature, rendering it
+        useless?).
+        """
         self.register_dependencies('shap_values', 'shap_values_cats')
         if not (self.hide_type and self.importance_type == 'shap'):
             self.register_dependencies('permutation_importances', 'permutation_importances_cats')
 
     def layout(self):
         return dbc.Card([
-            dbc.CardHeader([
-                make_hideable(
+            make_hideable(
+                dbc.CardHeader([
                     html.Div([
-                        html.H3(self.title, className="card-title"),
-                        html.H6(self.subtitle, className="card-subtitle"),
-                    ]), hide=self.hide_title),
-            ]),
+                        html.H3(self.title, className="card-title", id='importances-title-'+self.name),
+                        make_hideable(html.H6(self.subtitle, className='card-subtitle'), hide=self.hide_subtitle),
+                        dbc.Tooltip(self.description, target='importances-title-'+self.name),
+                    ]),
+            ]), hide=self.hide_title),
             dbc.CardBody([
                 dbc.Row([
                     make_hideable(
@@ -205,19 +220,20 @@ class ImportancesComponent(ExplainerComponent):
                         ], md=3), self.hide_depth),
                     make_hideable(
                         dbc.Col([
-                            dbc.FormGroup(
-                            [
+                            dbc.FormGroup([
                                 dbc.Label("Grouping:", id='importances-group-cats-label-'+self.name),
                                 dbc.Tooltip("Group onehot encoded categorical variables together", 
                                             target='importances-group-cats-label-'+self.name),
-                                dbc.RadioButton(
-                                    id='importances-group-cats-'+self.name, 
-                                    className="form-check-input",
-                                    checked=self.cats),
-                                dbc.Label("Group Cats",
-                                        html_for='importances-group-cats-'+self.name,
-                                        className="form-check-label"),
-                            ], check=True, id='importances-group-cats-form-'+self.name), 
+                                dbc.Checklist(
+                                    options=[
+                                        {"label": "Group cats", "value": True},
+                                    ],
+                                    value=[True] if self.cats else [],
+                                    id='importances-group-cats-'+self.name,
+                                    inline=True,
+                                    switch=True,
+                                ),
+                            ]),
                         ]),  self.hide_cats),    
                     make_hideable(
                             dbc.Col([self.selector.layout()
@@ -237,26 +253,27 @@ class ImportancesComponent(ExplainerComponent):
         @app.callback(  
             Output('importances-graph-'+self.name, 'figure'),
             [Input('importances-depth-'+self.name, 'value'),
-             Input('importances-group-cats-'+self.name, 'checked'),
+             Input('importances-group-cats-'+self.name, 'value'),
              Input('importances-permutation-or-shap-'+self.name, 'value'),
              Input('pos-label-'+self.name, 'value')],
         )
         def update_importances(depth, cats, permutation_shap, pos_label):
             return self.explainer.plot_importances(
                         kind=permutation_shap, topx=depth, 
-                        cats=cats, pos_label=pos_label)
+                        cats=bool(cats), pos_label=pos_label)
 
 
 class PdpComponent(ExplainerComponent):
     def __init__(self, explainer, title="Partial Dependence Plot", name=None,
                     subtitle="How does the prediction change if you change one feature?",
                     hide_col=False, hide_index=False, hide_cats=False,
-                    hide_title=False, hide_selector=False,
+                    hide_title=False,  hide_subtitle=False, hide_selector=False,
                     hide_dropna=False, hide_sample=False, 
                     hide_gridlines=False, hide_gridpoints=False,
                     feature_input_component=None,
                     pos_label=None, col=None, index=None, cats=True,
-                    dropna=True, sample=100, gridlines=50, gridpoints=10, **kwargs):
+                    dropna=True, sample=100, gridlines=50, gridpoints=10,
+                    description=None, **kwargs):
         """Show Partial Dependence Plot component
 
         Args:
@@ -272,6 +289,7 @@ class PdpComponent(ExplainerComponent):
             hide_index (bool, optional): Hide index selector. Defaults to False.
             hide_cats (bool, optional): Hide group cats toggle. Defaults to False.
             hide_title (bool, optional): Hide title, Defaults to False.
+            hide_subtitle (bool, optional): Hide subtitle. Defaults to False.
             hide_selector (bool, optional): hide pos label selectors. Defaults to False.
             hide_dropna (bool, optional): Hide drop na's toggle Defaults to False.
             hide_sample (bool, optional): Hide sample size input. Defaults to False.
@@ -289,6 +307,8 @@ class PdpComponent(ExplainerComponent):
             sample (int, optional): Sample size to calculate average partial dependence. Defaults to 100.
             gridlines (int, optional): Number of ice lines to display in plot. Defaults to 50.
             gridpoints (int, optional): Number of breakpoints on horizontal axis Defaults to 10.
+            description (str, optional): Tooltip to display when hover over
+                component title. When None default text is shown. 
         """
         super().__init__(explainer, title, name)
 
@@ -303,7 +323,7 @@ class PdpComponent(ExplainerComponent):
         if self.feature_input_component is not None:
             self.hide_index = True
             
-        self.description = f"""
+        if self.description is None: self.description = f"""
         The partial dependence plot (pdp) show how the model prediction would
         change if you change one particular feature. The plot shows you a sample
         of observations and how these observations would change with this
@@ -317,14 +337,14 @@ class PdpComponent(ExplainerComponent):
 
     def layout(self):
         return dbc.Card([
-                dbc.CardHeader([
-                    make_hideable(
-                        html.Div([
-                            html.H3(self.title, id='pdp-title-'+self.name),
-                            html.H6(self.subtitle, className="card-subtitle"),
-                            dbc.Tooltip(self.description, target='pdp-title-'+self.name),
-                        ]), hide=self.hide_title),
-                ]),
+                make_hideable(
+                    dbc.CardHeader([
+                            html.Div([
+                                html.H3(self.title, id='pdp-title-'+self.name),
+                                make_hideable(html.H6(self.subtitle, className='card-subtitle'), hide=self.hide_subtitle),
+                                dbc.Tooltip(self.description, target='pdp-title-'+self.name),
+                            ]), 
+                    ]), hide=self.hide_title),
                 dbc.CardBody([
                     dbc.Row([
                         make_hideable(
@@ -353,19 +373,20 @@ class PdpComponent(ExplainerComponent):
                         ], width=2), hide=self.hide_selector),
                         make_hideable(
                             dbc.Col([
-                                dbc.Label("Grouping:", id='pdp-group-cats-label-'+self.name),
-                                dbc.Tooltip("Group onehot encoded categorical variables together", 
-                                            target='pdp-group-cats-label-'+self.name),
-                                dbc.FormGroup(
-                                [
-                                    dbc.RadioButton(
-                                        id='pdp-group-cats-'+self.name, 
-                                        className="form-check-input",
-                                        checked=self.cats),
-                                    dbc.Label("Group Cats",
-                                            html_for='pdp-group-cats-'+self.name, 
-                                            className="form-check-label"),
-                                ], check=True),
+                                dbc.FormGroup([
+                                    dbc.Label("Grouping:", id='pdp-group-cats-label-'+self.name),
+                                    dbc.Tooltip("Group onehot encoded categorical variables together", 
+                                                target='pdp-group-cats-label-'+self.name),
+                                    dbc.Checklist(
+                                        options=[
+                                            {"label": "Group cats", "value": True},
+                                        ],
+                                        value=[True] if self.cats else [],
+                                        id='pdp-group-cats-'+self.name,
+                                        inline=True,
+                                        switch=True,
+                                    ),
+                                ]),
                             ], md=2), hide=self.hide_cats),
                     ], form=True),
                     dbc.Row([
@@ -379,21 +400,20 @@ class PdpComponent(ExplainerComponent):
                 dbc.CardFooter([
                     dbc.Row([
                         make_hideable(
-                            dbc.Col([ #
-                                dbc.Label("Drop na:",id='pdp-dropna-label-'+self.name ),
-                                dbc.Tooltip(f"drop all observations with feature values equal to {self.explainer.na_fill}"
-                                            " from the plot. This prevents the filler values from "
-                                            "ruining the x-axis.", target='pdp-dropna-label-'+self.name ),
-                                dbc.FormGroup(
-                                [
-                                    dbc.RadioButton(
-                                        id='pdp-dropna-'+self.name, 
-                                        className="form-check-input",
-                                        checked=self.dropna),
-                                    dbc.Label("Drop na's",
-                                            html_for='pdp-dropna-'+self.name, 
-                                            className="form-check-label"),
-                                ], check=True),
+                            dbc.Col([
+                                dbc.FormGroup([
+                                    dbc.Tooltip("Drop all observations with feature values "
+                                            f"equal to {self.explainer.na_fill} from the plot. "
+                                            "This prevents the filler values from ruining the x-axis.", 
+                                                target='pdp-dropna-'+self.name),
+                                    dbc.Checklist(
+                                        options=[{"label": "Drop na_fill", "value": True}],
+                                        value=[True] if self.dropna else [],
+                                        id='pdp-dropna-'+self.name,
+                                        inline=True,
+                                        switch=True,
+                                    ),
+                                ]),
                             ]), hide=self.hide_dropna),
                         make_hideable(
                             dbc.Col([ 
@@ -428,12 +448,12 @@ class PdpComponent(ExplainerComponent):
         
         @app.callback(
             Output('pdp-col-'+self.name, 'options'),
-            [Input('pdp-group-cats-'+self.name, 'checked')],
+            [Input('pdp-group-cats-'+self.name, 'value')],
             [State('pos-label-'+self.name, 'value')]
         )
         def update_pdp_graph(cats, pos_label):
             col_options = [{'label': col, 'value':col} 
-                                for col in self.explainer.columns_ranked_by_shap(cats, pos_label=pos_label)]
+                                for col in self.explainer.columns_ranked_by_shap(bool(cats), pos_label=pos_label)]
             return col_options
         
         if self.feature_input_component is None:
@@ -441,7 +461,7 @@ class PdpComponent(ExplainerComponent):
                 Output('pdp-graph-'+self.name, 'figure'),
                 [Input('pdp-index-'+self.name, 'value'),
                  Input('pdp-col-'+self.name, 'value'),
-                 Input('pdp-dropna-'+self.name, 'checked'),
+                 Input('pdp-dropna-'+self.name, 'value'),
                  Input('pdp-sample-'+self.name, 'value'),
                  Input('pdp-gridlines-'+self.name, 'value'),
                  Input('pdp-gridpoints-'+self.name, 'value'),
@@ -449,13 +469,13 @@ class PdpComponent(ExplainerComponent):
             )
             def update_pdp_graph(index, col, drop_na, sample, gridlines, gridpoints, pos_label):
                 return self.explainer.plot_pdp(col, index, 
-                    drop_na=drop_na, sample=sample, gridlines=gridlines, gridpoints=gridpoints, 
+                    drop_na=bool(drop_na), sample=sample, gridlines=gridlines, gridpoints=gridpoints, 
                     pos_label=pos_label)
         else:
             @app.callback(
                 Output('pdp-graph-'+self.name, 'figure'),
                 [Input('pdp-col-'+self.name, 'value'),
-                 Input('pdp-dropna-'+self.name, 'checked'),
+                 Input('pdp-dropna-'+self.name, 'value'),
                  Input('pdp-sample-'+self.name, 'value'),
                  Input('pdp-gridlines-'+self.name, 'value'),
                  Input('pdp-gridpoints-'+self.name, 'value'),
@@ -465,15 +485,15 @@ class PdpComponent(ExplainerComponent):
             def update_pdp_graph(col, drop_na, sample, gridlines, gridpoints, pos_label, *inputs):
                 X_row = self.explainer.get_row_from_input(inputs)
                 return self.explainer.plot_pdp(col, X_row=X_row,
-                    drop_na=drop_na, sample=sample, gridlines=gridlines, gridpoints=gridpoints, 
+                    drop_na=bool(drop_na), sample=sample, gridlines=gridlines, gridpoints=gridpoints, 
                     pos_label=pos_label)
 
 
 class FeatureInputComponent(ExplainerComponent):
     def __init__(self, explainer, title="Feature Input", name=None,
                     subtitle="Adjust the feature values to change the prediction",
-                    hide_title=False, hide_index=False, 
-                    index=None, **kwargs):
+                    hide_title=False,  hide_subtitle=False, hide_index=False, 
+                    index=None, description=None, **kwargs):
         """Interaction Dependence Component.
 
         Args:
@@ -486,8 +506,11 @@ class FeatureInputComponent(ExplainerComponent):
                         it's unique. Defaults to None.
             subtitle (str): subtitle
             hide_title (bool, optional): hide the title
+            hide_subtitle (bool, optional): Hide subtitle. Defaults to False.
             hide_index (bool, optional): hide the index selector
             index (str, int, optional): default index
+            description (str, optional): Tooltip to display when hover over
+                component title. When None default text is shown. 
             
         """
         super().__init__(explainer, title, name)
@@ -504,7 +527,8 @@ class FeatureInputComponent(ExplainerComponent):
                                 for feature in self._input_features]
         self._feature_callback_inputs = [Input('feature-input-'+feature+'-input-'+self.name, 'value') for feature in self._input_features]
         self._feature_callback_outputs = [Output('feature-input-'+feature+'-input-'+self.name, 'value') for feature in self._input_features] 
-        self.description = """Adjust the input values to see predictions for what if scenarios."""
+        if self.description is None: self.description = """
+        Adjust the input values to see predictions for what if scenarios."""
         
     def _generate_dash_input(self, col, cats, cats_dict):
         if col in cats:
@@ -525,14 +549,14 @@ class FeatureInputComponent(ExplainerComponent):
         
     def layout(self):
         return dbc.Card([
-            dbc.CardHeader([
-                make_hideable(
-                    html.Div([
-                        html.H3(self.title, id='feature-input-title-'+self.name),
-                        html.H6(self.subtitle, className="card-subtitle"),
-                        dbc.Tooltip(self.description, target='feature-input-title-'+self.name),
-                    ]), hide=self.hide_title),
-            ]),
+            make_hideable(
+                dbc.CardHeader([
+                        html.Div([
+                            html.H3(self.title, id='feature-input-title-'+self.name),
+                            make_hideable(html.H6(self.subtitle, className='card-subtitle'), hide=self.hide_subtitle),
+                            dbc.Tooltip(self.description, target='feature-input-title-'+self.name),
+                        ]), 
+                ]), hide=self.hide_title),
             dbc.CardBody([
                 dbc.Row([
                     make_hideable(
@@ -571,9 +595,10 @@ class FeatureInputComponent(ExplainerComponent):
 
 class WhatIfComponent(ExplainerComponent):
     def __init__(self, explainer, title="What if...", name=None,
-                    hide_title=False, hide_index=False, hide_selector=False,
-                    hide_contributions=False, hide_pdp=False,
-                    index=None, pdp_col=None, pos_label=None, **kwargs):
+                    hide_title=False,  hide_subtitle=False, hide_index=False, 
+                    hide_selector=False, hide_contributions=False, hide_pdp=False,
+                    index=None, pdp_col=None, pos_label=None, description=None,
+                    **kwargs):
         """Interaction Dependence Component.
 
         Args:
@@ -585,6 +610,7 @@ class WhatIfComponent(ExplainerComponent):
                         If None then random uuid is generated to make sure 
                         it's unique. Defaults to None.
             hide_title (bool, optional): hide the title
+            hide_subtitle (bool, optional): Hide subtitle. Defaults to False.
             hide_index (bool, optional): hide the index selector
             hide_selector (bool, optional): hide the pos_label selector
             hide_contributions (bool, optional): hide the contributions graph
@@ -593,7 +619,8 @@ class WhatIfComponent(ExplainerComponent):
             pdp_col (str, optional): default pdp feature col
             pos_label ({int, str}, optional): initial pos label. 
                         Defaults to explainer.pos_label
-            
+            description (str, optional): Tooltip to display when hover over
+                component title. When None default text is shown. 
         """
         super().__init__(explainer, title, name)
 
@@ -637,14 +664,14 @@ class WhatIfComponent(ExplainerComponent):
         
     def layout(self):
         return dbc.Card([
-            dbc.CardHeader([
-                dbc.Row([
-                    make_hideable(
-                        dbc.Col([
-                            html.H1("What if...analysis")
-                        ]), hide=self.hide_title)
-                ]),
-            ]),
+            make_hideable(
+                dbc.CardHeader([
+                    dbc.Row([
+                            dbc.Col([
+                                html.H1(self.title)
+                            ]), 
+                    ]),
+                ]), hide=self.hide_title),
             dbc.CardBody([
                 dbc.Row([
                     make_hideable(
