@@ -24,12 +24,14 @@ from ..dashboard_methods import *
 class RegressionRandomIndexComponent(ExplainerComponent):
     def __init__(self, explainer, title="Select Random Index", name=None,
                         subtitle="Select from list or pick at random",
-                        hide_title=False, hide_index=False, hide_pred_slider=False,
+                        hide_title=False,   hide_subtitle=False,
+                        hide_index=False, hide_pred_slider=False,
                         hide_residual_slider=False, hide_pred_or_y=False,
                         hide_abs_residuals=False, hide_button=False,
                         index=None, pred_slider=None, y_slider=None,
                         residual_slider=None, abs_residual_slider=None,
-                        pred_or_y="preds", abs_residuals=True, round=2, **kwargs):
+                        pred_or_y="preds", abs_residuals=True, round=2,
+                        description=None, **kwargs):
         """Select a random index subject to constraints component
 
         Args:
@@ -42,6 +44,7 @@ class RegressionRandomIndexComponent(ExplainerComponent):
                         it's unique. Defaults to None.
             subtitle (str): subtitle
             hide_title (bool, optional): hide title
+            hide_subtitle (bool, optional): Hide subtitle. Defaults to False.
             hide_index (bool, optional): Hide index selector.
                         Defaults to False.
             hide_pred_slider (bool, optional): Hide prediction slider.
@@ -69,11 +72,13 @@ class RegressionRandomIndexComponent(ExplainerComponent):
             abs_residuals (bool, optional): Initial use residuals or absolute
                         residuals. Defaults to True.
             round (int, optional): rounding used for slider spacing. Defaults to 2.
+            description (str, optional): Tooltip to display when hover over
+                component title. When None default text is shown. 
         """
         super().__init__(explainer, title, name)
         assert self.explainer.is_regression, \
             ("explainer is not a RegressionExplainer so the RegressionRandomIndexComponent "
-            " will not work. Try using the ClassifierRandomIndexComponent instead.")
+             "will not work. Try using the ClassifierRandomIndexComponent instead.")
 
         self.index_name = 'random-index-reg-index-'+self.name
 
@@ -111,9 +116,14 @@ class RegressionRandomIndexComponent(ExplainerComponent):
             assert (len(self.abs_residual_slider)==2 and self.abs_residual_slider[0]<=self.abs_residual_slider[1]), \
                 "abs_residual_slider should be a list of a [lower_bound, upper_bound]!"
 
+        self.y_slider = [float(y) for y in self.y_slider]
+        self.pred_slider = [float(p) for p in self.pred_slider]
+        self.residual_slider = [float(r) for r in self.residual_slider]
+        self.abs_residual_slider = [float(a) for a in self.abs_residual_slider]
+
         assert self.pred_or_y in ['preds', 'y'], "pred_or_y should be in ['preds', 'y']!"
 
-        self.description = f"""
+        if self.description is None: self.description = f"""
         You can select a {self.explainer.index_name} directly by choosing it 
         from the dropdown (if you start typing you can search inside the list),
         or hit the Random {self.explainer.index_name} button to randomly select
@@ -127,14 +137,14 @@ class RegressionRandomIndexComponent(ExplainerComponent):
 
     def layout(self):
         return dbc.Card([
-            dbc.CardHeader([
-                make_hideable(
+            make_hideable(
+                dbc.CardHeader([
                     html.Div([
                         html.H3(f"Select {self.explainer.index_name}", id='random-index-reg-title-'+self.name),
-                        html.H6(self.subtitle, className='card-subtitle'),
+                        make_hideable(html.H6(self.subtitle, className='card-subtitle'), hide=self.hide_subtitle),
                         dbc.Tooltip(self.description, target='random-index-reg-title-'+self.name),
-                    ]), hide=self.hide_title),
-            ]),
+                    ]), 
+                ]), hide=self.hide_title),
             dbc.CardBody([
                 dbc.Row([
                     make_hideable(
@@ -164,12 +174,12 @@ class RegressionRandomIndexComponent(ExplainerComponent):
                                                         target='random-index-reg-pred-slider-label-'+self.name),
                                             dcc.RangeSlider(
                                                 id='random-index-reg-pred-slider-'+self.name,
-                                                min=self.explainer.preds.min(),
-                                                max=self.explainer.preds.max(),
+                                                min=float(self.explainer.preds.min()),
+                                                max=float(self.explainer.preds.max()),
                                                 step=np.float_power(10, -self.round),
                                                 value=[self.pred_slider[0], self.pred_slider[1]],
-                                                marks={self.explainer.preds.min(): str(np.round(self.explainer.preds.min(), self.round)),
-                                                    self.explainer.preds.max(): str(np.round(self.explainer.preds.max(), self.round))},
+                                                marks={float(self.explainer.preds.min()): str(np.round(self.explainer.preds.min(), self.round)),
+                                                    float(self.explainer.preds.max()): str(np.round(self.explainer.preds.max(), self.round))},
                                                 allowCross=False,
                                                 tooltip = {'always_visible' : False}
                                             )
@@ -188,12 +198,12 @@ class RegressionRandomIndexComponent(ExplainerComponent):
                                             target='random-index-reg-y-slider-label-'+self.name),
                                             dcc.RangeSlider(
                                                 id='random-index-reg-y-slider-'+self.name,
-                                                min=self.explainer.y.min(),
-                                                max=self.explainer.y.max(),
+                                                min=float(self.explainer.y.min()),
+                                                max=float(self.explainer.y.max()),
                                                 step=np.float_power(10, -self.round),
                                                 value=[self.y_slider[0], self.y_slider[1]],
-                                                marks={self.explainer.y.min(): str(np.round(self.explainer.y.min(), self.round)),
-                                                    self.explainer.y.max(): str(np.round(self.explainer.y.max(), self.round))},
+                                                marks={float(self.explainer.y.min()): str(np.round(self.explainer.y.min(), self.round)),
+                                                    float(self.explainer.y.max()): str(np.round(self.explainer.y.max(), self.round))},
                                                 allowCross=False,
                                                 tooltip = {'always_visible' : False}
                                             )
@@ -216,12 +226,12 @@ class RegressionRandomIndexComponent(ExplainerComponent):
                                             target='random-index-reg-residual-slider-label-'+self.name),
                                         dcc.RangeSlider(
                                             id='random-index-reg-residual-slider-'+self.name,
-                                            min=self.explainer.residuals.min(),
-                                            max=self.explainer.residuals.max(),
+                                            min=float(self.explainer.residuals.min()),
+                                            max=float(self.explainer.residuals.max()),
                                             step=np.float_power(10, -self.round),
                                             value=[self.residual_slider[0], self.residual_slider[1]],
-                                            marks={self.explainer.residuals.min(): str(np.round(self.explainer.residuals.min(), self.round)),
-                                                self.explainer.residuals.max(): str(np.round(self.explainer.residuals.max(), self.round))},
+                                            marks={float(self.explainer.residuals.min()): str(np.round(self.explainer.residuals.min(), self.round)),
+                                                float(self.explainer.residuals.max()): str(np.round(self.explainer.residuals.max(), self.round))},
                                             allowCross=False,
                                             tooltip={'always_visible' : False}
                                         )
@@ -241,12 +251,12 @@ class RegressionRandomIndexComponent(ExplainerComponent):
                                             target='random-index-reg-abs-residual-slider-label'+self.name),
                                         dcc.RangeSlider(
                                             id='random-index-reg-abs-residual-slider-'+self.name,
-                                            min=self.explainer.abs_residuals.min(),
-                                            max=self.explainer.abs_residuals.max(),
+                                            min=float(self.explainer.abs_residuals.min()),
+                                            max=float(self.explainer.abs_residuals.max()),
                                             step=np.float_power(10, -self.round),
                                             value=[self.abs_residual_slider[0], self.abs_residual_slider[1]],
-                                            marks={self.explainer.abs_residuals.min(): str(np.round(self.explainer.abs_residuals.min(), self.round)),
-                                                self.explainer.abs_residuals.max(): str(np.round(self.explainer.abs_residuals.max(), self.round))},
+                                            marks={float(self.explainer.abs_residuals.min()): str(np.round(self.explainer.abs_residuals.min(), self.round)),
+                                                float(self.explainer.abs_residuals.max()): str(np.round(self.explainer.abs_residuals.max(), self.round))},
                                             allowCross=False,
                                             tooltip={'always_visible' : False}
                                         )
@@ -398,8 +408,10 @@ class RegressionRandomIndexComponent(ExplainerComponent):
 
 class RegressionPredictionSummaryComponent(ExplainerComponent):
     def __init__(self, explainer, title="Prediction", name=None,
-                    hide_index=False, hide_title=False, hide_table=False,
-                    index=None,  round=3, **kwargs):
+                    hide_index=False, hide_title=False, 
+                    hide_subtitle=False, hide_table=False,
+                    index=None,  round=3, description=None,
+                    **kwargs):
         """Shows a summary for a particular prediction
 
         Args:
@@ -412,19 +424,28 @@ class RegressionPredictionSummaryComponent(ExplainerComponent):
                         it's unique. Defaults to None.
             hide_index (bool, optional): hide index selector. Defaults to False.
             hide_title (bool, optional): hide title. Defaults to False.
+            hide_subtitle (bool, optional): Hide subtitle. Defaults to False.
             hide_table (bool, optional): hide the results table
             index ({int, str}, optional): Index to display prediction summary for. Defaults to None.
+            description (str, optional): Tooltip to display when hover over
+                component title. When None default text is shown. 
         """
         super().__init__(explainer, title, name)
 
         self.index_name = 'reg-prediction-index-'+self.name
 
+        if self.description is None: self.description = f"""
+        Shows the predicted {self.explainer.target} and the observed {self.explainer.target},
+        as well as the difference between the two (residual)
+        """
+
     def layout(self):
         return dbc.Card([
-            dbc.CardHeader([
-                make_hideable(
-                html.H3(self.title), hide=self.hide_title), 
-            ]),
+            make_hideable(
+                dbc.CardHeader([
+                    html.H3(self.title, id='reg-prediction-title-'+self.name, className='card-title'),
+                    dbc.Tooltip(self.description, target='reg-prediction-title-'+self.name),
+                ]), hide=self.hide_title), 
             dbc.CardBody([
                 dbc.Row([
                     make_hideable(
@@ -460,8 +481,9 @@ class RegressionPredictionSummaryComponent(ExplainerComponent):
 class PredictedVsActualComponent(ExplainerComponent):
     def __init__(self, explainer, title="Predicted vs Actual", name=None,
                     subtitle="How close is the predicted value to the observed?",
-                    hide_title=False, hide_log_x=False, hide_log_y=False,
-                    logs=False, log_x=False, log_y=False, **kwargs):
+                    hide_title=False, hide_subtitle=False, hide_log_x=False, hide_log_y=False,
+                    logs=False, log_x=False, log_y=False, description=None,
+                    **kwargs):
         """Shows a plot of predictions vs y.
 
         Args:
@@ -474,17 +496,20 @@ class PredictedVsActualComponent(ExplainerComponent):
                         it's unique. Defaults to None.
             subtitle (str): subtitle
             hide_title (bool, optional) Hide the title. Defaults to False.
+            hide_subtitle (bool, optional): Hide subtitle. Defaults to False.
             hide_log_x (bool, optional): Hide the log_x toggle. Defaults to False.
             hide_log_y (bool, optional): Hide the log_y toggle. Defaults to False.
             logs (bool, optional): Whether to use log axis. Defaults to False.
             log_x (bool, optional): log only x axis. Defaults to False.
             log_y (bool, optional): log only y axis. Defaults to False.
+            description (str, optional): Tooltip to display when hover over
+                component title. When None default text is shown. 
         """
         super().__init__(explainer, title, name)
         
         self.logs, self.log_x, self.log_y = logs, log_x, log_y
 
-        self.description = f"""
+        if self.description is None: self.description = f"""
         Plot shows the observed {self.explainer.target} and the predicted 
         {self.explainer.target} in the same plot. A perfect model would have
         all the points on the diagonal (predicted matches observed). The further
@@ -495,14 +520,14 @@ class PredictedVsActualComponent(ExplainerComponent):
 
     def layout(self):
         return dbc.Card([
-            dbc.CardHeader([
-                make_hideable(
+            make_hideable(
+                dbc.CardHeader([
                     html.Div([
                         html.H3(self.title, id='pred-vs-actual-title-'+self.name),
-                        html.H6(self.subtitle, className='card-subtitle'),
+                        make_hideable(html.H6(self.subtitle, className='card-subtitle'), hide=self.hide_subtitle),
                         dbc.Tooltip(self.description, target='pred-vs-actual-title-'+self.name),
-                    ]), hide=self.hide_title),
-            ]),
+                    ]), 
+                ]), hide=self.hide_title),
             dbc.CardBody([
                 dbc.Row([
                     make_hideable(
@@ -560,8 +585,10 @@ class PredictedVsActualComponent(ExplainerComponent):
 class ResidualsComponent(ExplainerComponent):
     def __init__(self, explainer, title="Residuals", name=None,
                     subtitle="How much is the model off?",
-                    hide_title=False, hide_pred_or_actual=False, hide_ratio=False,
-                    pred_or_actual="vs_pred", residuals="difference", **kwargs):
+                    hide_title=False, hide_subtitle=False, 
+                    hide_pred_or_actual=False, hide_ratio=False,
+                    pred_or_actual="vs_pred", residuals="difference",
+                    description=None, **kwargs):
         """Residuals plot component
 
         Args:
@@ -574,6 +601,7 @@ class ResidualsComponent(ExplainerComponent):
                         it's unique. Defaults to None.
             subtitle (str): subtitle
             hide_title (bool, optional) Hide the title. Defaults to False.
+            hide_subtitle (bool, optional): Hide subtitle. Defaults to False.
             hide_pred_or_actual (bool, optional): hide vs predictions or vs 
                         actual for x-axis toggle. Defaults to False.
             hide_ratio (bool, optional): hide residual type dropdown. Defaults to False.
@@ -582,13 +610,15 @@ class ResidualsComponent(ExplainerComponent):
                         Defaults to "vs_pred".
             residuals (str, {'difference', 'ratio', 'log-ratio'} optional): 
                     How to calcualte residuals. Defaults to 'difference'.
+            description (str, optional): Tooltip to display when hover over
+                component title. When None default text is shown. 
         """
         super().__init__(explainer, title, name)
 
         assert residuals in ['difference', 'ratio', 'log-ratio'], \
             ("parameter residuals should in ['difference', 'ratio', 'log-ratio']"
              f" but you passed residuals={residuals}")
-        self.description = f"""
+        if self.description is None: self.description = f"""
         The residuals are the difference between the observed {self.explainer.target}
         and predicted {self.explainer.target}. In this plot you can check if 
         the residuals are higher or lower for higher/lower actual/predicted outcomes. 
@@ -599,14 +629,14 @@ class ResidualsComponent(ExplainerComponent):
 
     def layout(self):
         return dbc.Card([
-            dbc.CardHeader([
-                make_hideable(
+            make_hideable(
+                dbc.CardHeader([
                     html.Div([
                         html.H3(self.title, id='residuals-title-'+self.name),
-                        html.H6(self.subtitle, className='card-subtitle'),
+                        make_hideable(html.H6(self.subtitle, className='card-subtitle'), hide=self.hide_subtitle),
                         dbc.Tooltip(self.description, target='residuals-title-'+self.name),
-                    ]), hide=self.hide_title),
-            ]),
+                    ]), 
+                ]), hide=self.hide_title),
             dbc.CardBody([
                 dbc.Row([
                     dbc.Col([
@@ -665,10 +695,11 @@ class ResidualsComponent(ExplainerComponent):
 class RegressionVsColComponent(ExplainerComponent):
     def __init__(self, explainer, title="Plot vs feature", name=None,
                     subtitle="Are predictions and residuals correlated with features?",
-                    hide_title=False, hide_col=False, hide_ratio=False, hide_cats=False, 
+                    hide_title=False, hide_subtitle=False, 
+                    hide_col=False, hide_ratio=False, hide_cats=False, 
                     hide_points=False, hide_winsor=False,
                     col=None, display='difference', cats=True, 
-                    points=True, winsor=0, **kwargs):
+                    points=True, winsor=0, description=None, **kwargs):
         """Show residuals, observed or preds vs a particular Feature component
 
         Args:
@@ -681,6 +712,7 @@ class RegressionVsColComponent(ExplainerComponent):
                         it's unique. Defaults to None.
             subtitle (str): subtitle
             hide_title (bool, optional) Hide the title. Defaults to False.
+            hide_subtitle (bool, optional): Hide subtitle. Defaults to False.
             hide_col (bool, optional): Hide de column selector. Defaults to False.
             hide_ratio (bool, optional): Hide the  toggle. Defaults to False.
             hide_cats (bool, optional): Hide group cats toggle. Defaults to False.
@@ -694,6 +726,8 @@ class RegressionVsColComponent(ExplainerComponent):
                     for categorical cols. Defaults to True
             winsor (int, 0-50, optional): percentage of outliers to winsor out of 
                     the y-axis. Defaults to 0.
+            description (str, optional): Tooltip to display when hover over
+                component title. When None default text is shown. 
         """
         super().__init__(explainer, title, name)
 
@@ -704,7 +738,7 @@ class RegressionVsColComponent(ExplainerComponent):
             ("parameter display should in {'observed', 'predicted', 'difference', 'ratio', 'log-ratio'}"
              f" but you passed display={self.display}!")
 
-        self.description = f"""
+        if self.description is None: self.description = f"""
         This plot shows either residuals (difference between observed {self.explainer.target}
         and predicted {self.explainer.target}) plotted against the values of different features,
         or the observed or predicted {self.explainer.target}.
@@ -715,14 +749,14 @@ class RegressionVsColComponent(ExplainerComponent):
 
     def layout(self):
         return dbc.Card([
-            dbc.CardHeader([
-                make_hideable(
-                html.Div([
-                    html.H3(self.title, id='reg-vs-col-title-'+self.name),
-                    html.H6(self.subtitle, className='card-subtitle'),
-                    dbc.Tooltip(self.description, target='reg-vs-col-title-'+self.name),
+            make_hideable(
+                dbc.CardHeader([
+                    html.Div([
+                        html.H3(self.title, id='reg-vs-col-title-'+self.name),
+                        make_hideable(html.H6(self.subtitle, className='card-subtitle'), hide=self.hide_subtitle),
+                        dbc.Tooltip(self.description, target='reg-vs-col-title-'+self.name),
+                    ]), 
                 ]), hide=self.hide_title),
-            ]),
             dbc.CardBody([
                 dbc.Row([
                     make_hideable(
@@ -754,19 +788,18 @@ class RegressionVsColComponent(ExplainerComponent):
                             ], md=4), hide=self.hide_ratio),
                     make_hideable(
                             dbc.Col([
-                                dbc.Label("Grouping:", id='reg-vs-col-group-cats-label-'+self.name),
-                                dbc.Tooltip("group onehot encoded features together.",
-                                            target='reg-vs-col-group-cats-label-'+self.name),
-                                dbc.FormGroup(
-                                [
-                                    dbc.RadioButton(
-                                        id='reg-vs-col-group-cats-'+self.name, 
-                                        className="form-check-input",
-                                        checked=self.cats),
-                                    dbc.Label("Group Cats",
-                                            html_for='reg-vs-col-group-cats-'+self.name,
-                                            className="form-check-label"),
-                                ], check=True),
+                                dbc.FormGroup([
+                                    dbc.Label("Grouping:", id='reg-vs-col-group-cats-label-'+self.name),
+                                    dbc.Tooltip("Group onehot encoded categorical variables together", 
+                                                target='reg-vs-col-group-cats-label-'+self.name),
+                                    dbc.Checklist(
+                                        options=[{"label": "Group cats", "value": True}],
+                                        value=[True] if self.cats else [],
+                                        id='reg-vs-col-group-cats-'+self.name,
+                                        inline=True,
+                                        switch=True,
+                                    ),
+                                ]),
                             ], md=2), self.hide_cats),
                 ]),
                 dbc.Row([
@@ -788,59 +821,64 @@ class RegressionVsColComponent(ExplainerComponent):
                             dbc.Input(id='reg-vs-col-winsor-'+self.name, 
                                     value=self.winsor,
                                 type="number", min=0, max=49, step=1),
-                        ], md=2), hide=self.hide_winsor),  
+                        ], md=4), hide=self.hide_winsor),  
                     make_hideable(
                         dbc.Col([
-                            dbc.Label("Points:", id='reg-vs-col-show-points-label-'+self.name),
-                            dbc.Tooltip("For categorical features, display a point cloud next to the violin plot.", 
-                                    target='reg-vs-col-show-points-label-'+self.name),
-                            dbc.FormGroup(
-                            [
-                                dbc.RadioButton(
-                                    id='reg-vs-col-show-points-'+self.name, 
-                                    className="form-check-input",
-                                    checked=self.points),
-                                dbc.Label("Show points",
-                                        html_for='reg-vs-col-show-points-'+self.name,
-                                        className="form-check-label"),
-                            ], check=True),
-                        ],  md=3), self.hide_points),
+                            html.Div([
+                                dbc.FormGroup([
+                                        dbc.Label("Scatter:"),
+                                        dbc.Tooltip("For categorical features, display "
+                                                "a point cloud next to the violin plots.", 
+                                                    target='reg-vs-col-show-points-'+self.name),
+                                        dbc.Checklist(
+                                            options=[{"label": "Show point cloud", "value": True}],
+                                            value=[True] if self.points else [],
+                                            id='reg-vs-col-show-points-'+self.name,
+                                            inline=True,
+                                            switch=True,
+                                        ),
+                                    ]),
+                            ], id='reg-vs-col-show-points-div-'+self.name)
+                        ],  md=4), self.hide_points),
                 ])
             ])
         ])
 
     def register_callbacks(self, app):
         @app.callback(
-            Output('reg-vs-col-graph-'+self.name, 'figure'),
+            [Output('reg-vs-col-graph-'+self.name, 'figure'),
+             Output('reg-vs-col-show-points-div-'+self.name, 'style')],
             [Input('reg-vs-col-col-'+self.name, 'value'),
              Input('reg-vs-col-display-type-'+self.name, 'value'),
-             Input('reg-vs-col-show-points-'+self.name, 'checked'),
+             Input('reg-vs-col-show-points-'+self.name, 'value'),
              Input('reg-vs-col-winsor-'+self.name, 'value')],
         )
         def update_residuals_graph(col, display, points, winsor):
+            style = {} if col in self.explainer.cats else dict(display="none")
             if display == 'observed':
                 return self.explainer.plot_y_vs_feature(
-                        col, points=points, winsor=winsor, dropna=True)
+                        col, points=bool(points), winsor=winsor, dropna=True), style
             elif display == 'predicted':
                 return self.explainer.plot_preds_vs_feature(
-                        col, points=points, winsor=winsor, dropna=True)
+                        col, points=bool(points), winsor=winsor, dropna=True), style
             else:
                 return self.explainer.plot_residuals_vs_feature(
-                            col, residuals=display, points=points, 
-                            winsor=winsor, dropna=True)
+                            col, residuals=display, points=bool(points), 
+                            winsor=winsor, dropna=True), style
 
         @app.callback(
             Output('reg-vs-col-col-'+self.name, 'options'),
-            [Input('reg-vs-col-group-cats-'+self.name, 'checked')])
+            [Input('reg-vs-col-group-cats-'+self.name, 'value')])
         def update_dependence_shap_scatter_graph(cats):
             return [{'label': col, 'value': col} 
-                for col in self.explainer.columns_ranked_by_shap(cats)]
+                for col in self.explainer.columns_ranked_by_shap(bool(cats))]
 
 
 class RegressionModelSummaryComponent(ExplainerComponent):
     def __init__(self, explainer, title="Model Summary", name=None, 
                     subtitle="Quantitative metrics for model performance",
-                    hide_title=False, round=3, **kwargs):
+                    hide_title=False, hide_subtitle=False, 
+                    round=3, description=None, **kwargs):
         """Show model summary statistics (RMSE, MAE, R2) component
 
         Args:
@@ -853,10 +891,13 @@ class RegressionModelSummaryComponent(ExplainerComponent):
                         it's unique. Defaults to None.
             subtitle (str): subtitle
             hide_title (bool, optional): hide title
+            hide_subtitle (bool, optional): Hide subtitle. Defaults to False.
             round (int): rounding to perform to metric floats.
+            description (str, optional): Tooltip to display when hover over
+                component title. When None default text is shown. 
         """
         super().__init__(explainer, title, name)
-        self.description = f"""
+        if self.description is None: self.description = f"""
         In the table below you can find a number of regression performance 
         metrics that describe how well the model is able to predict 
         {self.explainer.target}.
@@ -873,14 +914,14 @@ class RegressionModelSummaryComponent(ExplainerComponent):
                                                     "reg-model-summary-div-hover", 
                                                     self.name)
         return dbc.Card([
-            dbc.CardHeader([
-                make_hideable(
+            make_hideable(
+                dbc.CardHeader([
                     html.Div([
                         html.H3(self.title, id='reg-model-summary-title-'+self.name),
-                        html.H6(self.subtitle, className='card-subtitle'),
+                        make_hideable(html.H6(self.subtitle, className='card-subtitle'), hide=self.hide_subtitle),
                         dbc.Tooltip(self.description, target='reg-model-summary-title-'+self.name),
-                    ]), hide=self.hide_title),
-            ]),
+                    ]), 
+                ]), hide=self.hide_title),
             dbc.CardBody([
                 metrics_table,
                 *tooltips
