@@ -6,6 +6,8 @@ __all__ = [
     'PosLabelSelector',
     'make_hideable',
     'get_dbc_tooltips',
+    'update_params',
+    'update_kwargs',
 ]
 
 import sys
@@ -64,6 +66,16 @@ def delegates_doc(to=None, keep=False):
     return _f
 
 
+def update_params(kwargs, **params):
+    """kwargs override params"""
+    return dict(params, **kwargs)
+
+
+def update_kwargs(kwargs, **params):
+    """params override kwargs"""
+    return dict(kwargs, **params)
+
+
 def get_dbc_tooltips(dbc_table, desc_dict, hover_id, name):
                 """Return a dbc.Table and a list of dbc.Tooltips.
 
@@ -145,9 +157,9 @@ class ExplainerComponent(ABC):
     the same type in a layout. 
 
     Important:
-        define your callbacks in _register_callbacks() and
+        define your callbacks in component_callbacks() and
         ExplainerComponent will register callbacks of subcomponents in addition
-        to _register_callbacks() when calling register_callbacks()
+        to component_callbacks() when calling register_callbacks()
     """
     def __init__(self, explainer, title=None, name=None):
         """initialize the ExplainerComponent
@@ -309,19 +321,22 @@ class ExplainerComponent(ABC):
         All element id's should append +self.name to make sure they are unique."""
         return None
 
-    def _register_callbacks(self, app):
-        """register callbacks specific to this ExplainerComponent"""
-        pass
+    def component_callbacks(self, app):
+        """register callbacks specific to this ExplainerComponent."""
+        if hasattr(self, "_register_callbacks"):
+            print("Warning: the use of _register_callbacks() will be deprecated!"
+                  " Use component_callbacks() from now on...")
+            self._register_callbacks(app)
 
     def register_callbacks(self, app):
         """First register callbacks of all subcomponents, then call
-        _register_callbacks(app)
+        component_callbacks(app)
         """
         if not hasattr(self, '_components'):
             self._components = []
         for comp in self._components:
             comp.register_callbacks(app)
-        self._register_callbacks(app)
+        self.component_callbacks(app)
 
 
 class PosLabelSelector(ExplainerComponent):
