@@ -73,8 +73,8 @@ def instantiate_component(component, explainer, **kwargs):
 class ExplainerTabsLayout:
     def __init__(self, explainer, tabs,
                  title='Model Explainer',
-                 hide_title=False,
-                 hide_selector=False,
+                 header_hide_title=False,
+                 header_hide_selector=False,
                  block_selector_callbacks=False,
                  pos_label=None,
                  fluid=True,
@@ -89,8 +89,8 @@ class ExplainerTabsLayout:
             tabs (list[ExplainerComponent class or instance]): list of
                 ExplainerComponent class definitions or instances.
             title (str, optional): [description]. Defaults to 'Model Explainer'.
-            hide_title (bool, optional): Hide the title. Defaults to False.
-            hide_selector (bool, optional): Hide the positive label selector. 
+            header_hide_title (bool, optional): Hide the title. Defaults to False.
+            header_hide_selector (bool, optional): Hide the positive label selector. 
                         Defaults to False.
             block_selector_callbacks (bool, optional): block the callback of the
                         pos label selector. Useful to avoid clashes when you
@@ -101,11 +101,11 @@ class ExplainerTabsLayout:
             fluid (bool, optional): Stretch layout to fill space. Defaults to False.
         """
         self.title = title
-        self.hide_title = hide_title
-        self.hide_selector = hide_selector
+        self.header_hide_title = header_hide_title
+        self.header_hide_selector = header_hide_selector
         self.block_selector_callbacks = block_selector_callbacks
         if self.block_selector_callbacks:
-            self.hide_selector = True
+            self.header_hide_selector = True
         self.fluid = fluid
         
         self.selector = PosLabelSelector(explainer, pos_label=pos_label)
@@ -121,11 +121,11 @@ class ExplainerTabsLayout:
                 make_hideable(
                     dbc.Col([
                         html.H1(self.title)
-                    ], width="auto"), hide=self.hide_title),
+                    ], width="auto"), hide=self.header_hide_title),
                 make_hideable(
                     dbc.Col([
                         self.selector.layout()
-                    ], md=3), hide=self.hide_selector),
+                    ], md=3), hide=self.header_hide_selector),
             ], justify="start"),
             dcc.Tabs(id="tabs", value=self.tabs[0].name, 
                         children=[dcc.Tab(label=tab.title, id=tab.name, value=tab.name,
@@ -159,8 +159,8 @@ class ExplainerTabsLayout:
 class ExplainerPageLayout(ExplainerComponent):
     def __init__(self, explainer, component,
                  title='Model Explainer',
-                 hide_title=False,
-                 hide_selector=False,
+                 header_hide_title=False,
+                 header_hide_selector=False,
                  block_selector_callbacks=False,
                  pos_label=None,
                  fluid=False,
@@ -177,8 +177,8 @@ class ExplainerPageLayout(ExplainerComponent):
             component (ExplainerComponent class or instance): ExplainerComponent 
                         class definition or instance.
             title (str, optional): [description]. Defaults to 'Model Explainer'.
-            hide_title (bool, optional): Hide the title. Defaults to False.
-            hide_selector (bool, optional): Hide the positive label selector.
+            header_hide_title (bool, optional): Hide the title. Defaults to False.
+            header_hide_selector (bool, optional): Hide the positive label selector.
                         Defaults to False.
             block_selector_callbacks (bool, optional): block the callback of the
                         pos label selector. Useful to avoid clashes when you
@@ -189,11 +189,11 @@ class ExplainerPageLayout(ExplainerComponent):
             fluid (bool, optional): Stretch layout to fill space. Defaults to False.
         """
         self.title = title
-        self.hide_title = hide_title
-        self.hide_selector = hide_selector
+        self.header_hide_title = header_hide_title
+        self.header_hide_selector = header_hide_selector
         self.block_selector_callbacks = block_selector_callbacks
         if self.block_selector_callbacks:
-            self.hide_selector = True
+            self.header_hide_selector = True
         self.fluid = fluid
         
         self.selector = PosLabelSelector(explainer, pos_label=pos_label)
@@ -209,11 +209,11 @@ class ExplainerPageLayout(ExplainerComponent):
                 make_hideable(
                     dbc.Col([
                         html.H1(self.title)
-                    ], width="auto"), hide=self.hide_title),
+                    ], width="auto"), hide=self.header_hide_title),
                 make_hideable(
                     dbc.Col([
                         self.selector.layout()
-                    ], md=3), hide=self.hide_selector),
+                    ], md=3), hide=self.header_hide_selector),
             ], justify="start"),
             self.page.layout()
         ], fluid=self.fluid)
@@ -251,6 +251,7 @@ class ExplainerDashboard:
                  mode="dash",
                  width=1000,
                  height=800,
+                 bootstrap=None,
                  external_stylesheets=None,
                  server=True,
                  url_base_pathname=None,
@@ -318,8 +319,12 @@ class ExplainerDashboard:
                     Defaults to True.
             width(int, optional): width of notebook output cell in pixels, defaults to 1000.
             height(int, optional): height of notebookn output cell in pixels, defaults to 800.
-            external_stylesheets(list, optional): attach dbc themes e.g. 
-                `external_stylesheets=[dbc.themes.FLATLY]`. 
+            bootstrap (str, optional): link to bootstrap url. Can use dbc.themese
+                to generate the url, e.g. bootstrap=dbc.themes.FLATLY. Defaults
+                to default bootstrap theme that is stored in the /assets folder
+                so that it works even behind a firewall. 
+            external_stylesheets(list, optional): additional external stylesheets
+                to add. (for themes use the bootstrap parameter) 
             server (Flask instance or bool): either an instance of an existing Flask
                 server to tie the dashboard to, or True in which case a new Flask
                 server is created. 
@@ -363,6 +368,13 @@ class ExplainerDashboard:
                     "mode='external', mode='inline' or mode='jupyterlab' "
                     "to keep the notebook interactive while the dashboard "
                     "is running...", flush=True)
+        
+        if self.bootstrap is not None:
+            bootstrap_theme = self.bootstrap if isinstance(self.bootstrap, str) else dbc.themes.BOOTSTRAP
+            if self.external_stylesheets is None:
+                self.external_stylesheets = [bootstrap_theme]
+            else:
+                self.external_stylesheets.append(bootstrap_theme)
 
         self.app = self._get_dash_app()
         if logins is not None:
@@ -403,6 +415,9 @@ class ExplainerDashboard:
             if shap_dependence:
                 tabs.append(ShapDependenceComposite)
             if shap_interaction:
+                print("Warning: calculating shap interaction values can be slow! "
+                        "Pass shap_interaction=False to remove interactions tab.", 
+                        flush=True)
                 tabs.append(ShapInteractionsComposite)
             if decision_trees:
                 tabs.append(DecisionTreesComposite)
@@ -412,42 +427,58 @@ class ExplainerDashboard:
         print("Generating layout...")  
         if isinstance(tabs, list):
             tabs = [self._convert_str_tabs(tab) for tab in tabs]
-            explainer_layout = ExplainerTabsLayout(explainer, tabs, title, 
-                            hide_title=header_hide_title, 
-                            hide_selector=header_hide_selector, 
-                            block_selector_callbacks=block_selector_callbacks,
-                            pos_label=pos_label,
-                            fluid=fluid, **kwargs)
+            self.explainer_layout = ExplainerTabsLayout(explainer, tabs, title, 
+                            **update_kwargs(kwargs, 
+                            header_hide_title=self.header_hide_title, 
+                            header_hide_selector=self.header_hide_selector, 
+                            block_selector_callbacks=self.block_selector_callbacks,
+                            pos_label=self.pos_label,
+                            fluid=fluid))
         else:
             tabs = self._convert_str_tabs(tabs)
-            explainer_layout = ExplainerPageLayout(explainer, tabs, title, 
-                            hide_title=header_hide_title, 
-                            hide_selector=header_hide_selector, 
-                            block_selector_callbacks=block_selector_callbacks,
-                            pos_label=pos_label,
-                            fluid=fluid, **kwargs)
+            self.explainer_layout = ExplainerPageLayout(explainer, tabs, title, 
+                            **update_kwargs(kwargs,
+                            header_hide_title=self.header_hide_title, 
+                            header_hide_selector=self.header_hide_selector, 
+                            block_selector_callbacks=self.block_selector_callbacks,
+                            pos_label=self.pos_label,
+                            fluid=self.fluid))
 
-        self.app.layout = explainer_layout.layout()
+        self.app.layout = self.explainer_layout.layout()
 
         print("Calculating dependencies...", flush=True)  
-        explainer_layout.calculate_dependencies()
+        self.explainer_layout.calculate_dependencies()
+        print("Reminder: you can store the explainer (including calculated "
+                "dependencies) with explainer.dump('explainer.joblib') and "
+                "reload with e.g. ClassifierExplainer.from_file('explainer.joblib')",
+                flush=True)
         print("Registering callbacks...", flush=True)
-        explainer_layout.register_callbacks(self.app)
+        self.explainer_layout.register_callbacks(self.app)
 
     @classmethod
-    def from_config(cls, arg1, arg2=None):
-        """ Four different ways of loading an ExplainerDashboard from config:
+    def from_config(cls, arg1, arg2=None, **update_params):
+        """Loading a dashboard from a configuration .yaml file. You can either
+        pass both an explainer and a yaml file generated with 
+        ExplainerDashboard.to_yaml("dashboard.yaml"):
+        
+          db = ExplainerDashboard.from_config(explainer, "dashboard.yaml")
+        
+        When you specify an explainerfile in to_yaml with 
+        ExplainerDashboard.to_yaml("dashboard.yaml", explainerfile="explainer.joblib"),
+        you can also pass just the .yaml:
 
           db = ExplainerDashboard.from_config("dashboard.yaml")
-          db = ExplainerDashboard.from_config(config_dict)
-          db = ExplainerDashboard.from_config(explainer, "dashboard.yaml")
+
+        You can also load the explainerfile seperately:
+
           db = ExplainerDashboard.from_config("explainer.joblib", "dashboard.yaml")
 
         Args:
             arg1 (explainer or config): arg1 should either be a config (yaml or dict),
                 or an explainer (instance or str/Path).
             arg2 ([type], optional): If arg1 is an explainer, arg2 should be config.
-
+            update_params (dict): You can override parameters in the the yaml 
+                config by passing additional kwargs to .from_config()
 
         Returns:
             ExplainerDashboard
@@ -484,10 +515,24 @@ class ExplainerDashboard:
                     "arg2 should be a .yaml file or a dict!")
 
         dashboard_params = config['dashboard']['params']
+
+        for k, v in update_params.items():
+            if k in dashboard_params:
+                dashboard_params[k] = v
+            elif 'kwargs' in dashboard_params:
+                dashboard_params['kwargs'][k] = v
+            else:
+                dashboard_params['kwargs'] = dict(k=v)
+
+        if 'kwargs' in dashboard_params:
+            kwargs = dashboard_params.pop('kwargs')
+        else:
+            kwargs = {}
+
         tabs = cls._yamltabs_to_tabs(dashboard_params['tabs'], explainer)
         del dashboard_params['tabs']
 
-        return cls(explainer, tabs, **dashboard_params)
+        return cls(explainer, tabs, **dashboard_params, **kwargs)
 
 
     def _store_params(self, no_store=None, no_attr=None, no_param=None):
@@ -515,6 +560,9 @@ class ExplainerDashboard:
         frame = sys._getframe(1)
         args = frame.f_code.co_varnames[1:frame.f_code.co_argcount]
         args_dict = {arg: frame.f_locals[arg] for arg in args}
+
+        if 'kwargs' in frame.f_locals:
+            args_dict['kwargs'] = frame.f_locals['kwargs']
         
         if isinstance(no_store, bool) and no_store:
             return
@@ -678,11 +726,12 @@ class ExplainerDashboard:
         elif self.mode == 'external':
             if not self.is_colab:
                 print(f"Starting ExplainerDashboard on http://localhost:{port}\n"
-                      f"You can terminate it with ExplainerDashboard.terminate({port})", flush=True)
+                      "You can terminate the dashboard with "
+                      f"ExplainerDashboard.terminate({port})", flush=True)
             self.app.run_server(port=port, mode=self.mode, **kwargs)
         elif self.mode in ['inline', 'jupyterlab']:
             print(f"Starting ExplainerDashboard inline (terminate it with "
-                    "ExplainerDashboard.terminate({port}))", flush=True)
+                  f"ExplainerDashboard.terminate({port}))", flush=True)
             self.app.run_server(port=port, mode=self.mode, 
                                 width=self.width, height=self.height, **kwargs)
         else:
@@ -699,8 +748,6 @@ class ExplainerDashboard:
             ExplainerDashboard(explainer, mode='external').run(port=8050)
 
             ExplainerDashboard.terminate(8050) 
-            db = ExplainerDashboard(explainer)
-            db.terminate(8050)
 
         Args:
             port (int): port on which the dashboard is running. 
